@@ -9,7 +9,8 @@ add.alpha <- function(col, alpha = 1) {
   }
   apply(
     sapply(col, col2rgb) / 255, 2,
-    function(x)
+    function(x) {
       rgb(x[1], x[2], x[3], alpha = alpha)
+    }
   )
 }
