@@ -8,10 +8,10 @@ calcular.optimo.criterio <- function(i.curva.map, i.criterio = 2.8) {
   d.y <- diff(y.s)
   d.x <- x[2:length(x)]
   if (any(d.y < i.criterio)) {
-    optimo <- min(d.x[d.y < i.criterio], na.rm = T) - 1
+    optimo <- min(d.x[d.y < i.criterio], na.rm = TRUE) - 1
     optimo <- max(optimo, 1)
   } else {
-    optimo <- max(d.x, na.rm = T)
+    optimo <- max(d.x, na.rm = TRUE)
   }
   resultados <- i.curva.map[x == optimo, ]
   datos <- data.frame(weeks = d.x, slope = d.y)
