@@ -75,22 +75,22 @@ memsurveillance.animated <- function(i.current,
                                      i.epidemic.thresholds = NA,
                                      i.intensity.thresholds = NA,
                                      i.output = ".",
-                                     i.animated.graph.file = T,
+                                     i.animated.graph.file = TRUE,
                                      i.animated.graph.file.name = "animated",
                                      i.fps = 2,
                                      i.loop = 0,
-                                     i.remove = T, ...) {
+                                     i.remove = TRUE, ...) {
   if (!requireNamespace("magick", quietly = TRUE)) {
     cat("magick package needed for this function to work. Please install it.\n")
     return(NULL)
   } else {
     if (is.null(dim(i.current))) stop("Incorrect number of dimensions, input must be a data.frame.", call. = FALSE) else if (!(ncol(i.current) == 1)) stop("Incorrect number of dimensions, only one season required.", call. = FALSE)
 
-    y.max <- max(i.current, na.rm = T)
+    y.max <- max(i.current, na.rm = TRUE)
 
-    if (!is.numeric(i.epidemic.thresholds) | length(i.epidemic.thresholds) == 1) i.epidemic.thresholds <- rep(NA, 2) else y.max <- max(max(i.epidemic.thresholds, na.rm = T), y.max)
-    if (!is.numeric(i.intensity.thresholds) | length(i.intensity.thresholds) == 1) i.intensity.thresholds <- rep(NA, 3) else y.max <- max(max(i.intensity.thresholds, na.rm = T), y.max)
-    for (i in 1:NROW(i.current)) {
+    if (!is.numeric(i.epidemic.thresholds) || length(i.epidemic.thresholds) == 1) i.epidemic.thresholds <- rep(NA, 2) else y.max <- max(max(i.epidemic.thresholds, na.rm = TRUE), y.max)
+    if (!is.numeric(i.intensity.thresholds) || length(i.intensity.thresholds) == 1) i.intensity.thresholds <- rep(NA, 3) else y.max <- max(max(i.intensity.thresholds, na.rm = TRUE), y.max)
+    for (i in seq_len(NROW(i.current))) {
       temp1 <- data.frame(name = i.current[1:i, ])
       names(temp1) <- names(i.current)
       rownames(temp1) <- rownames(i.current)[1:i]
@@ -103,28 +103,20 @@ memsurveillance.animated <- function(i.current,
         i.graph.file.name = paste(i.animated.graph.file.name, "_", i, sep = ""),
         i.range.y = c(0, y.max), ...
       )
-      # shell(paste("convert  \"",i.output,"/",i.animated.graph.file.name,"_",i,".tiff\" -resize 800x600 \"",i.output,"/",i.animated.graph.file.name,"_",i,".png\"",sep=""))
-      # file.remove(paste(i.output,"/",i.animated.graph.file.name,"_",i,".tiff",sep=""))
       if (i.animated.graph.file) {
         imgfile <- (paste(i.output, "/", i.animated.graph.file.name, "_", i, ".tiff", sep = ""))
         if (i == 1) imgfilem <- magick::image_read(imgfile) else imgfilem <- c(imgfilem, magick::image_read(imgfile))
       }
     }
     if (i.animated.graph.file.name == "") graph.name <- paste(i.output, "/animated graph.gif", sep = "") else graph.name <- paste(i.output, "/", i.animated.graph.file.name, ".gif", sep = "")
-    # command<-paste("convert -delay ",i.delay," -loop ",i.loop,sep="")
-    # for (i in 1:NROW(i.current)) command<-paste(command," \"",i.output,"/",i.animated.graph.file.name,"_",i,".png\"",sep="")
-    # command<-paste(command, " \"",graph.name,"\"",sep="")
-    # if (i.animated.graph.file) shell(command)
     if (i.animated.graph.file) {
       anim <- magick::image_animate(imgfilem, fps = i.fps, loop = i.loop)
       magick::image_write(anim, path = graph.name)
     }
-    # if (i.remove) for (i in 1:NROW(i.current)) file.remove(paste(i.output,"/",i.animated.graph.file.name,"_",i,".png",sep=""))
-    if (i.remove) for (i in 1:NROW(i.current)) file.remove(paste(i.output, "/", i.animated.graph.file.name, "_", i, ".tiff", sep = ""))
+    if (i.remove) for (i in seq_len(NROW(i.current))) file.remove(paste(i.output, "/", i.animated.graph.file.name, "_", i, ".tiff", sep = ""))
 
-    # file.rename("Animated surveillance.gif",graph.name)
     cat(graph.name, "\n")
-    memsurveillance.animated.output <- list(
+    memsurveillanceanim.output <- list(
       graph.name = graph.name,
       param.current = i.current,
       param.epidemic.thresholds = i.epidemic.thresholds,
@@ -136,7 +128,7 @@ memsurveillance.animated <- function(i.current,
       param.loop = i.loop,
       param.remove = i.remove
     )
-    memsurveillance.animated.output$call <- match.call()
-    return(memsurveillance.animated.output)
+    memsurveillanceanim.output$call <- match.call()
+    return(memsurveillanceanim.output)
   }
 }
