@@ -10,12 +10,16 @@
 #'
 #' @param i.data Data frame of input data.
 #' @param i.param.values values to use in the i.param value of \code{memtiming}.
-#' @param i.graph create a graph with the outputs (T/F).
+#' @param i.graph create a graph with the outputs (T/FALSE).
 #' @param i.graph.file write the graph to a file.
 #' @param i.graph.file.name name of the output file.
 #' @param i.graph.title title of the graph.
 #' @param i.graph.subtitle subtitle of the graph.
 #' @param i.output output directory.
+#' @param i.labels.axis different labels used by output graphs
+#' @param i.labels.periods different labels used by output graphs
+#' @param i.labels.details different labels used by output graphs
+#' @param i.tolerance tolerance (in inches) when identifying points in the graph
 #'
 #' @return
 #' \code{optimum.by.inspection} returns a list.
@@ -59,17 +63,20 @@
 #' @importFrom graphics identify
 optimum.by.inspection <- function(i.data,
                                   i.param.values = seq(1.0, 5.0, 0.1),
-                                  i.graph = F,
-                                  i.graph.file = F,
+                                  i.graph = FALSE,
+                                  i.graph.file = FALSE,
                                   i.graph.file.name = "",
                                   i.graph.title = "",
                                   i.graph.subtitle = "",
-                                  i.output = ".") {
+                                  i.output = ".",
+                                  i.labels.axis = c("Week", "Weekly rate"),
+                                  i.labels.periods = c("Pre", "Epidemic", "Post"),
+                                  i.labels.details = c("Sensitivity", "Specificity", "First row represents real and second row observed pos/neg values"),
+                                  i.tolerance = 0.25) {
   semanas <- dim(i.data)[1]
   anios <- dim(i.data)[2]
   nombre.semana <- rownames(i.data)
   nombre.anios <- colnames(i.data)
-  numero.semana <- 1:semanas
   n.values <- length(i.param.values)
 
   i.timing.1 <- array(dim = c(anios, 2))
@@ -83,21 +90,21 @@ optimum.by.inspection <- function(i.data,
 
   for (i in 1:anios) {
     cur <- i.data[i]
-    itsnotok <- T
+    itsnotok <- TRUE
     while (itsnotok) {
-      memsur <- memsurveillance(cur, NA, NA,
-        i.graph.file = F, i.graph.title = nombre.anios[i],
+      memsurveillance(cur, NA, NA,
+        i.graph.file = FALSE, i.graph.title = nombre.anios[i],
         i.range.x = as.numeric(rownames(cur))[c(1, semanas)]
       )
       cat("Click on the FIRST epidemic week of this season\nDepending on the device used to plot the graph, you might need to click on FINISH (top-right corner)\n")
-      i.timing.1.1 <- identify(x = 1:semanas, y = as.numeric(as.matrix(cur)), labels = nombre.semana, n = 1, plot = F)
+      i.timing.1.1 <- identify(x = 1:semanas, y = as.numeric(as.matrix(cur)), labels = nombre.semana, n = 1, plot = FALSE, tolerance = i.tolerance)
       if (is.numeric(i.timing.1.1)) points(x = i.timing.1.1, y = cur[i.timing.1.1, ], pch = 1, col = col.points.alpha[1], lwd = 7)
       cat("Click on the LAST epidemic week of this season\nDepending on the device used to plot the graph, you might need to click on FINISH (top-right corner)\n\n")
-      i.timing.1.2 <- identify(x = 1:semanas, y = as.numeric(as.matrix(cur)), labels = nombre.semana, n = 1, plot = F)
+      i.timing.1.2 <- identify(x = 1:semanas, y = as.numeric(as.matrix(cur)), labels = nombre.semana, n = 1, plot = FALSE, tolerance = i.tolerance)
       if (is.numeric(i.timing.1.2)) points(x = i.timing.1.2, y = cur[i.timing.1.2, ], pch = 1, col = col.points.alpha[2], lwd = 7)
       cat("Epidemic week range selected is: [", nombre.semana[i.timing.1.1], ",", nombre.semana[i.timing.1.2], "]\n\n")
       i.timing.1.3 <- readline("Is that correct? (type Y or N)\t")
-      if (tolower(i.timing.1.3) %in% c("y", "ye", "yes")) itsnotok <- F
+      if (tolower(i.timing.1.3) %in% c("y", "ye", "yes")) itsnotok <- FALSE
     }
     i.timing.1.i <- c(i.timing.1.1, i.timing.1.2)
     i.timing.1[i, ] <- i.timing.1.i
@@ -108,13 +115,16 @@ optimum.by.inspection <- function(i.data,
       i.timing.2 <- calcular.optimo(curva.map, 2, i.param.deteccion)$resultados[4:5]
       resultado.j <- calcular.indicadores.2.timings(cur, i.timing.1.i, i.timing.2,
         i.timing.labels = c("inspection", i.param.deteccion.label),
-        i.graph.title = "Comparing", i.graph.file = F
+        i.graph.title = "Comparing", i.graph.file = FALSE,
+        i.labels.axis = i.labels.axis,
+        i.labels.periods = i.labels.periods,
+        i.labels.details = i.labels.details
       )$indicadores
       resultados.i[i, , j] <- as.numeric(resultado.j)
     }
   }
 
-  resultado <- data.frame(apply(resultados.i, c(3, 2), sum, na.rm = T))
+  resultado <- data.frame(apply(resultados.i, c(3, 2), sum, na.rm = TRUE))
   # sensibilidad
   resultado[7] <- resultado[3] / (resultado[3] + resultado[6])
   # especificidad
@@ -140,19 +150,19 @@ optimum.by.inspection <- function(i.data,
   names(resultados) <- c("value", tolower(colnames(resultado.j)))
 
   # Ranking 1: Rank(sensitivity) + Rank(specificity)
-  if (!any(!is.na(resultados$sensitivity)) | !any(!is.na(resultados$specificity))) {
+  if (!any(!is.na(resultados$sensitivity)) || !any(!is.na(resultados$specificity))) {
     rankings.1 <- NA
     optimo.1 <- NA
   } else {
-    rankings.1 <- rank(-resultados$sensitivity, na.last = T) + rank(-resultados$specificity, na.last = T)
+    rankings.1 <- rank(-resultados$sensitivity, na.last = TRUE) + rank(-resultados$specificity, na.last = TRUE)
     optimo.1 <- i.param.values[which.min(rankings.1)]
   }
   # Ranking 2: Rank(sensitivity x Rank specificity)
-  if (!any(!is.na(resultados$sensitivity)) | !any(!is.na(resultados$specificity))) {
+  if (!any(!is.na(resultados$sensitivity)) || !any(!is.na(resultados$specificity))) {
     rankings.2 <- NA
     optimo.2 <- NA
   } else {
-    rankings.2 <- rank(-resultados$sensitivity * resultados$specificity, na.last = T)
+    rankings.2 <- rank(-resultados$sensitivity * resultados$specificity, na.last = TRUE)
     optimo.2 <- i.param.values[which.min(rankings.2)]
   }
   # Ranking 3: Rank(positive.likehood.ratio)
@@ -160,7 +170,7 @@ optimum.by.inspection <- function(i.data,
     rankings.3 <- NA
     optimo.3 <- NA
   } else {
-    rankings.3 <- rank(-resultados$positive.likehood.ratio, na.last = T)
+    rankings.3 <- rank(-resultados$positive.likehood.ratio, na.last = TRUE)
     optimo.3 <- i.param.values[which.min(rankings.3)]
   }
   # Ranking 4: Rank(negative.likehood.ratio)
@@ -168,11 +178,11 @@ optimum.by.inspection <- function(i.data,
     rankings.4 <- NA
     optimo.4 <- NA
   } else {
-    rankings.4 <- rank(-resultados$negative.likehood.ratio, na.last = T)
+    rankings.4 <- rank(-resultados$negative.likehood.ratio, na.last = TRUE)
     optimo.4 <- i.param.values[which.min(rankings.4)]
   }
   # Ranking 5: Rank(sensitivity-specificity) + Rank(sensitivity+specificity) + Rank(sensitivity^2+specificity^2)
-  if (!any(!is.na(resultados$sensitivity)) | !any(!is.na(resultados$specificity))) {
+  if (!any(!is.na(resultados$sensitivity)) || !any(!is.na(resultados$specificity))) {
     rankings.5 <- NA
     optimo.5 <- NA
   } else {
@@ -187,7 +197,7 @@ optimum.by.inspection <- function(i.data,
     rankings.6 <- NA
     optimo.6 <- NA
   } else {
-    rankings.6 <- rank(-resultados$percent.agreement, na.last = T)
+    rankings.6 <- rank(-resultados$percent.agreement, na.last = TRUE)
     optimo.6 <- i.param.values[which.min(rankings.6)]
   }
   # Ranking 7: Rank(matthews.correlation.coefficient)
@@ -195,7 +205,7 @@ optimum.by.inspection <- function(i.data,
     rankings.7 <- NA
     optimo.7 <- NA
   } else {
-    rankings.7 <- rank(-resultados$matthews.correlation.coefficient, na.last = T)
+    rankings.7 <- rank(-resultados$matthews.correlation.coefficient, na.last = TRUE)
     optimo.7 <- i.param.values[which.min(rankings.7)]
   }
   # Ranking 8: Rank(Youden's J statistic=Youden's index)
@@ -203,7 +213,7 @@ optimum.by.inspection <- function(i.data,
     rankings.8 <- NA
     optimo.8 <- NA
   } else {
-    rankings.8 <- rank(-resultados$youdens.index, na.last = T)
+    rankings.8 <- rank(-resultados$youdens.index, na.last = TRUE)
     optimo.8 <- i.param.values[which.min(rankings.8)]
   }
 
@@ -237,7 +247,6 @@ optimum.by.inspection <- function(i.data,
   if (i.graph) {
     if (i.graph.file.name == "") graph.name <- "inspection analysis" else graph.name <- i.graph.file.name
 
-
     if (i.graph.subtitle != "") graph.title <- paste(i.graph.subtitle, " - ", graph.title, sep = "")
     if (i.graph.title != "") graph.title <- paste(i.graph.title, "\n", graph.title, sep = "")
 
@@ -249,14 +258,17 @@ optimum.by.inspection <- function(i.data,
       i.param.deteccion <- optimum$matthews
       i.param.deteccion.label <- format(round(i.param.deteccion, 1), digits = 3, nsmall = 1)
       i.timing.2 <- calcular.optimo(curva.map, 2, i.param.deteccion)$resultados[4:5]
-      dummmmyyyy <- calcular.indicadores.2.timings(cur, i.timing.1.i, i.timing.2,
+      calcular.indicadores.2.timings(cur, i.timing.1.i, i.timing.2,
         i.timing.labels = c("inspection", i.param.deteccion.label),
         i.graph.title = graph.title,
         i.graph.file = i.graph.file,
         i.graph.file.name = paste(graph.name, " - ", i, sep = ""),
-        i.output = i.output
+        i.output = i.output,
+        i.labels.axis = i.labels.axis,
+        i.labels.periods = i.labels.periods,
+        i.labels.details = i.labels.details
       )
-      if (!i.graph.file) dummmmyyyy <- readline("Press any key to continue\n")
+      if (!i.graph.file) readline("Press any key to continue\n")
     }
   }
 
