@@ -66,11 +66,11 @@ processPlots <- function(i.flu, i.output = ".", i.prefix = "") {
   summary(i.flu)
   sink()
 
-  write.table(round(i.flu$pre.post.intervals, 4), file = paste(salidas, "/", i.prefix, "Summary.txt", sep = ""), dec = ",", append = TRUE, quote = FALSE, sep = "\t", row.names = F, col.names = F)
+  write.table(round(i.flu$pre.post.intervals, 4), file = paste(salidas, "/", i.prefix, "Summary.txt", sep = ""), dec = ",", append = TRUE, quote = FALSE, sep = "\t", row.names = FALSE, col.names = FALSE)
   sink(file = paste(salidas, "/", i.prefix, "Summary.txt", sep = ""), append = TRUE)
   cat("\n\nEstimated starting and ending point of the influenza season and its 95% CL\n\n")
   sink()
-  write.table(i.flu$ci.start[1:2, ], file = paste(salidas, "/", i.prefix, "Summary.txt", sep = ""), dec = ",", append = TRUE, quote = FALSE, sep = "\t", row.names = F, col.names = F)
+  write.table(i.flu$ci.start[1:2, ], file = paste(salidas, "/", i.prefix, "Summary.txt", sep = ""), dec = ",", append = TRUE, quote = FALSE, sep = "\t", row.names = FALSE, col.names = FALSE)
   sink(file = paste(salidas, "/", i.prefix, "Summary.txt", sep = ""), append = TRUE)
   cat("\n\nLimits of the influenza season, relative and absolute position in weeks\n\n")
   sink()
@@ -79,7 +79,7 @@ processPlots <- function(i.flu, i.output = ".", i.prefix = "") {
     c(i.flu$mean.start, i.flu$mean.start + i.flu$mean.length - 1),
     c(semana.absoluta(i.flu$mean.start, i.flu$semana.inicio), semana.absoluta(i.flu$mean.start + i.flu$mean.length - 1, i.flu$semana.inicio))
   )
-  write.table(limites.temporada, file = paste(salidas, "/", i.prefix, "Summary.txt", sep = ""), dec = ",", append = TRUE, quote = FALSE, sep = "\t", row.names = F, col.names = F)
+  write.table(limites.temporada, file = paste(salidas, "/", i.prefix, "Summary.txt", sep = ""), dec = ",", append = TRUE, quote = FALSE, sep = "\t", row.names = FALSE, col.names = FALSE)
 
 
 
@@ -91,7 +91,7 @@ processPlots <- function(i.flu, i.output = ".", i.prefix = "") {
       filename = paste(salidas, "/", i.prefix, "Epidemics ", j, ".tiff", sep = ""), width = 8, height = 6, units = "in", pointsize = "12",
       compression = "lzw", bg = "white", res = 300, antialias = "none"
     )
-    opar <- par(mfrow = c(1, 1), mar = c(4, 4, 3, 10) + 0.1, xpd = T)
+    opar <- par(mfrow = c(1, 1), mar = c(4, 4, 3, 10) + 0.1, xpd = TRUE)
     tempdatos <- as.data.frame(cbind(1:semanas, i.flu$data[, j]))
     names(tempdatos) <- c("Week", "Rate")
     matplot(tempdatos[, 1],
@@ -104,7 +104,7 @@ processPlots <- function(i.flu, i.output = ".", i.prefix = "") {
       lty = c(1, 1),
       xaxt = "n"
     )
-    axis(1, at = 1:dim(tempdatos)[1], labels = rownames(i.flu$data), cex.axis = 1)
+    axis(1, at = seq_len(dim(tempdatos)[1]), labels = rownames(i.flu$data), cex.axis = 1)
     # pre
     puntos <- tempdatos
     puntos[i.flu$seasons.data[1, j, 1]:semanas, 2] <- NA
@@ -132,7 +132,7 @@ processPlots <- function(i.flu, i.output = ".", i.prefix = "") {
     dev.off()
     par(opar)
 
-    write.table(round(tempdatos, 2), file = paste(salidas, "/", i.prefix, "Epidemics ", j, ".txt", sep = ""), dec = ",", append = FALSE, quote = FALSE, sep = "\t", row.names = F, col.names = T)
+    write.table(round(tempdatos, 2), file = paste(salidas, "/", i.prefix, "Epidemics ", j, ".txt", sep = ""), dec = ",", append = FALSE, quote = FALSE, sep = "\t", row.names = FALSE, col.names = TRUE)
   }
 
   # Figure 2: MAP Curve
@@ -142,7 +142,7 @@ processPlots <- function(i.flu, i.output = ".", i.prefix = "") {
       filename = paste(salidas, "/", i.prefix, "MAP Curve ", j, ".tiff", sep = ""), width = 8, height = 6, units = "in", pointsize = "12",
       compression = "lzw", bg = "white", res = 300, antialias = "none"
     )
-    opar <- par(mfrow = c(1, 1), mar = c(4, 4, 3, 2) + 0.1, xpd = T)
+    opar <- par(mfrow = c(1, 1), mar = c(4, 4, 3, 2) + 0.1, xpd = TRUE)
 
     tempdatos <- i.flu$optimum[[j]]$map.curve
 
@@ -174,7 +174,7 @@ processPlots <- function(i.flu, i.output = ".", i.prefix = "") {
     )
     par(opar)
     dev.off()
-    write.table(round(tempdatos, 2), file = paste(salidas, "/", i.prefix, "MAP Curve ", j, ".txt", sep = ""), dec = ",", append = FALSE, quote = FALSE, sep = "\t", row.names = F, col.names = T)
+    write.table(round(tempdatos, 2), file = paste(salidas, "/", i.prefix, "MAP Curve ", j, ".txt", sep = ""), dec = ",", append = FALSE, quote = FALSE, sep = "\t", row.names = FALSE, col.names = TRUE)
   }
 
   # Figure 2.b : MAP Curve Slope for criterium 2
@@ -185,16 +185,15 @@ processPlots <- function(i.flu, i.output = ".", i.prefix = "") {
         filename = paste(salidas, "/", i.prefix, "MAP Curve Slope ", j, ".tiff", sep = ""), width = 8, height = 6, units = "in", pointsize = "12",
         compression = "lzw", bg = "white", res = 300, antialias = "none"
       )
-      opar <- par(mfrow = c(1, 1), mar = c(4, 4, 3, 2) + 0.1, xpd = T)
+      opar <- par(mfrow = c(1, 1), mar = c(4, 4, 3, 2) + 0.1, xpd = TRUE)
 
       i.curva.map <- i.flu$optimum[[j]]$map.curve
-      y.100 <- min((1:length(i.curva.map[, 2]))[round(i.curva.map[, 2], 2) == 100])
+      y.100 <- min((seq_len(length(i.curva.map[, 2])))[round(i.curva.map[, 2], 2) == 100])
       curva.map <- i.curva.map[1:y.100, ]
       x <- curva.map[, 1]
       y <- curva.map[, 2]
       y.s <- suavizado(y, 1)
       d.y <- diff(y.s)
-      optimo <- i.flu$optimum[[j]]$optimum.map[1]
 
       matplot(x[-length(x)], d.y,
         type = "l", col = "#808080", lty = c(1, 1),
@@ -214,7 +213,7 @@ processPlots <- function(i.flu, i.output = ".", i.prefix = "") {
       # Donde se alcanza
       points(
         x = c(i.flu$optimum[[j]]$optimum.map[1], i.flu$optimum[[j]]$optimum.map[1]),
-        y = c(0, max(d.y, na.rm = T)),
+        y = c(0, max(d.y, na.rm = TRUE)),
         type = "l", col = "#FFB401", lwd = 1
       )
       points(
@@ -230,7 +229,7 @@ processPlots <- function(i.flu, i.output = ".", i.prefix = "") {
       par(opar)
       dev.off()
 
-      write.table(round(cbind(x[-length(x)], d.y), 2), file = paste(salidas, "/", i.prefix, "MAP Curve Slope ", j, ".txt", sep = ""), dec = ",", append = FALSE, quote = FALSE, sep = "\t", row.names = F, col.names = T)
+      write.table(round(cbind(x[-length(x)], d.y), 2), file = paste(salidas, "/", i.prefix, "MAP Curve Slope ", j, ".txt", sep = ""), dec = ",", append = FALSE, quote = FALSE, sep = "\t", row.names = FALSE, col.names = TRUE)
     }
   }
 
@@ -239,29 +238,26 @@ processPlots <- function(i.flu, i.output = ".", i.prefix = "") {
 
   tempdatos <- as.data.frame(i.flu$season.scheme[, , 1])
   names(tempdatos) <- c(names(i.flu$param.data), "Optimal", "Period")
-  write.table(tempdatos, file = paste(salidas, "/", i.prefix, "Relative Positions.txt", sep = ""), dec = ",", append = FALSE, quote = FALSE, sep = "\t", row.names = F, col.names = T)
+  write.table(tempdatos, file = paste(salidas, "/", i.prefix, "Relative Positions.txt", sep = ""), dec = ",", append = FALSE, quote = FALSE, sep = "\t", row.names = FALSE, col.names = TRUE)
   tempdatos <- as.data.frame(i.flu$season.scheme[, , 2])
   names(tempdatos) <- c(names(i.flu$param.data), "Optimal", "Period")
-  write.table(tempdatos, file = paste(salidas, "/", i.prefix, "Absolute Positions.txt", sep = ""), dec = ",", append = FALSE, quote = FALSE, sep = "\t", row.names = F, col.names = T)
+  write.table(tempdatos, file = paste(salidas, "/", i.prefix, "Absolute Positions.txt", sep = ""), dec = ",", append = FALSE, quote = FALSE, sep = "\t", row.names = FALSE, col.names = TRUE)
 
   ## Figure 4 - Weekly incidence rates of the seasons matching their relative position in the model.
 
   tempdatos <- as.data.frame(cbind(1:semanas, i.flu$moving.epidemics))
   names(tempdatos) <- c("Week", names(i.flu$param.data))
-  write.table(round(tempdatos, 2), file = paste(salidas, "/", i.prefix, "Moving Epidemics.txt", sep = ""), dec = ",", append = FALSE, quote = FALSE, sep = "\t", row.names = F, col.names = T)
+  write.table(round(tempdatos, 2), file = paste(salidas, "/", i.prefix, "Moving Epidemics.txt", sep = ""), dec = ",", append = FALSE, quote = FALSE, sep = "\t", row.names = FALSE, col.names = TRUE)
   tiff(
     filename = paste(salidas, "/", i.prefix, "Moving Epidemics.tiff", sep = ""), width = 8, height = 6, units = "in", pointsize = "12",
     compression = "lzw", bg = "white", res = 300, antialias = "none"
   )
-  opar <- par(mfrow = c(1, 1), mar = c(4, 4, 3, 12) + 0.1, xpd = T)
+  opar <- par(mfrow = c(1, 1), mar = c(4, 4, 3, 12) + 0.1, xpd = TRUE)
 
   tipos <- rep(1, anios)
   anchos <- rep(2, anios)
-  # colores<-c(rgb(runif(anios-1),runif(anios-1),runif(anios-1)),"#FF0000")
   pal <- colorRampPalette(brewer.pal(4, "Spectral"))
   colores <- pal(anios)
-  # colores<-brewer.pal(anios,"Blues")
-  # limite.superior<-c(0,50+maxFixNA(i.flu$moving.epidemics))
   limite.superior <- c(0, 1.05 * maxFixNA(i.flu$moving.epidemics))
   rango.superior <- limite.superior[2] - limite.superior[1]
   matplot(tempdatos[, 1], tempdatos[, 2:(anios + 1)],
@@ -273,7 +269,7 @@ processPlots <- function(i.flu, i.output = ".", i.prefix = "") {
     font.axis = 1, font.lab = 1, font.main = 2, font.sub = 1, xaxt = "n"
   )
   axis(1,
-    at = 1:dim(tempdatos)[1],
+    at = seq_len(dim(tempdatos)[1]),
     labels = rownames(i.flu$data), cex.axis = 1
   )
   abline(
@@ -305,12 +301,12 @@ processPlots <- function(i.flu, i.output = ".", i.prefix = "") {
 
   tempdatos <- as.data.frame(cbind(1:semanas, i.flu$typ.curve, lineas.basicas))
   names(tempdatos) <- c("Week", "LowerCurve", "MeanCurve", "UpperCurve", "LowerThreshold", "MeanThreshold", "UpperThreshold")
-  write.table(round(tempdatos, 2), file = paste(salidas, "/", i.prefix, "MEM Model v1.txt", sep = ""), dec = ",", append = FALSE, quote = FALSE, sep = "\t", row.names = F, col.names = T)
+  write.table(round(tempdatos, 2), file = paste(salidas, "/", i.prefix, "MEM Model v1.txt", sep = ""), dec = ",", append = FALSE, quote = FALSE, sep = "\t", row.names = FALSE, col.names = TRUE)
   tiff(
     filename = paste(salidas, "/", i.prefix, "MEM Model v1.tiff", sep = ""), width = 8, height = 6, units = "in", pointsize = "12",
     compression = "lzw", bg = "white", res = 300, antialias = "none"
   )
-  opar <- par(mfrow = c(1, 1), mar = c(4, 4, 3, 10) + 0.1, xpd = T)
+  opar <- par(mfrow = c(1, 1), mar = c(4, 4, 3, 10) + 0.1, xpd = TRUE)
 
   tipos <- c(1, 1, 1, 0, 0, 2)
   anchos <- c(2, 2, 2, 0, 0, 2)
@@ -318,7 +314,6 @@ processPlots <- function(i.flu, i.output = ".", i.prefix = "") {
   # Limites normales
   dgraf <- cbind(i.flu$typ.curve, lineas.basicas)
   nulos <- is.na(dgraf[, 1]) | is.na(dgraf[, 3])
-  # limite.superior<-c(0,50+maxFixNA(dgraf))
   limite.superior <- c(0, 1.05 * maxFixNA(dgraf))
   matplot(1:semanas, dgraf,
     type = "l", lty = tipos, lwd = anchos, col = colores,
@@ -331,7 +326,7 @@ processPlots <- function(i.flu, i.output = ".", i.prefix = "") {
   )
   points(1:semanas, dgraf[, 2], col = "#808080", type = "l", lwd = 2)
 
-  axis(1, at = 1:dim(tempdatos)[1], labels = rownames(i.flu$data), cex.axis = 1)
+  axis(1, at = seq_len(dim(tempdatos)[1]), labels = rownames(i.flu$data), cex.axis = 1)
   x <- 4
   y <- dgraf[1, 6] * 1.2
   texto <- as.character(round(dgraf[1, 6], digits = 2))
@@ -363,12 +358,12 @@ processPlots <- function(i.flu, i.output = ".", i.prefix = "") {
   tempdatos <- as.data.frame(cbind(1:semanas, i.flu$typ.curve[, 2], lineas.basicas[, 3], limites.niveles.mas))
   etiquetas <- paste(round(limites.niveles, 2), " (", as.numeric(nombres.niveles) * 100, "%) ", sep = "")
   names(tempdatos) <- c("Week", "Threshold", etiquetas)
-  write.table(round(tempdatos, 2), file = paste(salidas, "/", i.prefix, "MEM Model v2.txt", sep = ""), dec = ",", append = FALSE, quote = FALSE, sep = "\t", row.names = F, col.names = T)
+  write.table(round(tempdatos, 2), file = paste(salidas, "/", i.prefix, "MEM Model v2.txt", sep = ""), dec = ",", append = FALSE, quote = FALSE, sep = "\t", row.names = FALSE, col.names = TRUE)
   tiff(
     filename = paste(salidas, "/", i.prefix, "MEM Model v2.tiff", sep = ""), width = 8, height = 6, units = "in", pointsize = "12",
     compression = "lzw", bg = "white", res = 300, antialias = "none"
   )
-  opar <- par(mfrow = c(1, 1), mar = c(4, 4, 3, 10) + 0.1, xpd = T)
+  opar <- par(mfrow = c(1, 1), mar = c(4, 4, 3, 10) + 0.1, xpd = TRUE)
 
   tipos <- c(1, 2, rep(2, times = n.niveles))
   anchos <- c(3, 2, rep(2, times = n.niveles))
@@ -382,7 +377,6 @@ processPlots <- function(i.flu, i.output = ".", i.prefix = "") {
   par(mfrow = c(1, 1))
   dgraf <- tempdatos[, -1]
   limite.superior <- c(0, 1.05 * maxFixNA(dgraf))
-  # cat("Lineas:",dim(dgraf)[2],"\n")
   matplot(1:semanas, dgraf,
     type = "l",
     main = paste("MEM Thresholds\n", substring(names(i.flu$param.data)[1], 1, nchar(names(i.flu$param.data)[1]) - 12)),
@@ -391,10 +385,9 @@ processPlots <- function(i.flu, i.output = ".", i.prefix = "") {
     font.axis = 1, font.lab = 1, font.main = 2, font.sub = 1,
     ylim = limite.superior, xaxt = "n"
   )
-  axis(1, at = 1:dim(tempdatos)[1], labels = rownames(i.flu$data), cex.axis = 1)
+  axis(1, at = seq_len(dim(tempdatos)[1]), labels = rownames(i.flu$data), cex.axis = 1)
   x <- c(limites.temporada[1, 1] - 5, 1 + rep(limites.temporada[1, 2], n.niveles))
   y <- c(lineas.basicas[1, 3], limites.niveles)
-  # texto<-c(paste("Threshold: ",round(lineas.basicas[1,3],2),sep=""),etiquetas)
   texto <- c(paste(round(lineas.basicas[1, 3], 2), sep = ""), etiquetas)
   posiciones <- c(3, rep(4, n.niveles))
   tamanios <- c(1.25, rep(1, n.niveles))
