@@ -13,9 +13,9 @@ transformseries.twowaves <- function(i.data,
                                      i.output = NA,
                                      i.prefix = "two waves",
                                      i.proportion = 0.15) {
-  if (is.na(i.proportion) | is.null(i.proportion)) i.proportion <- 0.15
-  if (is.na(i.scale) | is.null(i.scale)) i.scale <- 10000
-  if (is.na(i.model) | is.null(i.model)) i.model <- "V"
+  if (is.na(i.proportion) || is.null(i.proportion)) i.proportion <- 0.15
+  if (is.na(i.scale) || is.null(i.scale)) i.scale <- 10000
+  if (is.na(i.model) || is.null(i.model)) i.model <- "V"
   seasons <- names(i.data)
   n.seasons <- dim(i.data)[2]
   weeks <- rownames(i.data)
@@ -28,15 +28,27 @@ transformseries.twowaves <- function(i.data,
     resultados.i <- data.frame(rates = i.data[, i])
     rownames(resultados.i) <- weeks
     resultados.i$rates.no.miss <- fill.missing(resultados.i$rates)
-    total.rates <- sum(resultados.i$rates.no.miss, na.rm = T)
+    total.rates <- sum(resultados.i$rates.no.miss, na.rm = TRUE)
     x1 <- 1:n.weeks
     y1 <- round(resultados.i$rates.no.miss * i.scale / total.rates, 0)
     x2 <- x1[!is.na(y1)]
     y2 <- y1[!is.na(y1)]
     data.rep <- rep(x2, times = y2)
     # Sometimes densityMClust return errors, I have to check it
-    mixmdl.normal.v <- try(densityMclust(data.rep, G = 2, modelNames = "V", verbose = F), silent = T)
-    mixmdl.normal.e <- try(densityMclust(data.rep, G = 2, modelNames = "E", verbose = F), silent = T)
+    mixmdl.normal.v <- try(
+      {
+        setTimeLimit(cpu = 5, elapsed = Inf)
+        densityMclust(data.rep, G = 2, modelNames = "V", verbose = FALSE)
+      },
+      silent = TRUE
+    )
+    mixmdl.normal.e <- try(
+      {
+        setTimeLimit(cpu = 5, elapsed = Inf)
+        densityMclust(data.rep, G = 2, modelNames = "E", verbose = FALSE)
+      },
+      silent = TRUE
+    )
     if (i.model != "V") {
       if (!("try-error" %in% class(mixmdl.normal.e))) {
         mixmdl.normal <- mixmdl.normal.e
@@ -68,14 +80,13 @@ transformseries.twowaves <- function(i.data,
         temp1 <- NULL
       }
     }
-    temp2 <- merge(data.frame(week = 1:n.weeks, stringsAsFactors = F),
-      unique(data.frame(week = data.rep, classification = mixmdl.normal$classification, stringsAsFactors = F)),
-      by = "week", all.x = T
+    temp2 <- merge(data.frame(week = 1:n.weeks, stringsAsFactors = FALSE),
+      unique(data.frame(week = data.rep, classification = mixmdl.normal$classification, stringsAsFactors = FALSE)),
+      by = "week", all.x = TRUE
     )
     for (j in 2:NROW(temp2)) if (is.na(temp2$classification[j])) temp2$classification[j] <- temp2$classification[j - 1]
     for (j in (NROW(temp2) - 1):1) if (is.na(temp2$classification[j])) temp2$classification[j] <- temp2$classification[j + 1]
     # If the proportion of one of the normals is less than the param i.proportion then there is only one normal
-    # print(mixmdl.normal$parameters$pro)
     if (mixmdl.normal$parameters$pro[1] < i.proportion) {
       temp2$classification <- 2
     } else if (mixmdl.normal$parameters$pro[2] < i.proportion) {
@@ -90,18 +101,18 @@ transformseries.twowaves <- function(i.data,
     if (length(inicio.normal) > 0) {
       if (mixmdl.normal$parameters$mean[1] > inicio.normal) {
         temp2$classification <- 2
-        temp2$clasequ <- F
+        temp2$clasequ <- FALSE
       }
       if (mixmdl.normal$parameters$mean[2] < inicio.normal) {
         temp2$classification <- 1
-        temp2$clasequ <- F
+        temp2$clasequ <- FALSE
       }
     }
-    n.changes <- sum(temp2$clasequ, na.rm = T)
+    n.changes <- sum(temp2$clasequ, na.rm = TRUE)
     if (n.changes == 0) {
       # One single wave or transitions from 2 to 1, counting as only one wave
       # Option: fit new model with one normal
-      mixmdl.normal <- densityMclust(data.rep, G = 1, modelNames = "V", verbose = F)
+      mixmdl.normal <- densityMclust(data.rep, G = 1, modelNames = "V", verbose = FALSE)
       temp1 <- as.data.frame(cdensV(x1, parameters = mixmdl.normal$parameters))
       inicio.normal <- NA
       temp3 <- data.frame(
@@ -110,7 +121,7 @@ transformseries.twowaves <- function(i.data,
         season.sub.normal = 1,
         part1 = resultados.i$rates,
         part2 = NA,
-        stringsAsFactors = F
+        stringsAsFactors = FALSE
       )
     } else if (n.changes > 0) {
       # Two waves, overlapping
@@ -120,7 +131,7 @@ transformseries.twowaves <- function(i.data,
         season.sub.normal = c(rep(1, inicio.normal - 1), rep(2, n.weeks - inicio.normal + 1)),
         part1 = c(resultados.i$rates[1:(inicio.normal - 1)], rep(NA, n.weeks - inicio.normal + 1)),
         part2 = c(rep(NA, inicio.normal - 1), resultados.i$rates[inicio.normal:n.weeks]),
-        stringsAsFactors = F
+        stringsAsFactors = FALSE
       )
     }
     resultados.i <- cbind(resultados.i, temp3)
@@ -129,7 +140,7 @@ transformseries.twowaves <- function(i.data,
     resultados.i$coeficiente <- resultados.i$rates.no.miss / resultados.i$normal
     resultados.i$week <- 1:n.weeks
     if (!is.na(i.output)) {
-      outputdir <- file.path(getwd(), i.output)
+      outputdir <- file.path(i.output)
       if (!dir.exists(outputdir)) dir.create(outputdir)
       normal1 <- NULL
       normal2 <- NULL
@@ -137,8 +148,8 @@ transformseries.twowaves <- function(i.data,
       part2 <- NULL
       rates.no.miss <- NULL
       week <- NULL
-      axis.x.range.original <- range(resultados.i$week, na.rm = T)
-      axis.x.otick <- optimal.tickmarks(axis.x.range.original[1], axis.x.range.original[2], 10, i.include.min = T, i.include.max = T)
+      axis.x.range.original <- range(resultados.i$week, na.rm = TRUE)
+      axis.x.otick <- optimal.tickmarks(axis.x.range.original[1], axis.x.range.original[2], 10, i.include.min = TRUE, i.include.max = TRUE)
       axis.x.range <- axis.x.otick$range
       axis.x.ticks <- axis.x.otick$tickmarks
       axis.x.labels <- rownames(resultados.i)[axis.x.otick$tickmarks]
@@ -160,11 +171,10 @@ transformseries.twowaves <- function(i.data,
           geom_line(aes(x = week, y = normal2), color = "#59955C", size = 1, linetype = 4) +
           geom_vline(aes(xintercept = mixmdl.normal$parameters$mean[2]), linetype = 4, color = "#59955C")
       }
-      if (any(!is.na(resultados.i$part1)) & any(!is.na(resultados.i$part2))) {
+      if (any(!is.na(resultados.i$part1)) && any(!is.na(resultados.i$part2))) {
         p1 <- p1 +
           geom_vline(aes(xintercept = inicio.normal - 0.5), size = 1, linetype = 2, color = "#BF00BF")
       }
-      # ggsave(paste0(i.prefix, " (Season ", i, ").tif"), plot = p1, device = "tiff", scale = 1, width = 8, height = 6, units = "in", dpi = 150, path = outputdir)
       ggsave(paste0(i.prefix, " (Season ", i, ").png"), plot = p1, device = "png", scale = 1, width = 8, height = 6, units = "in", dpi = 150, path = outputdir)
     }
     detalles$nombre <- mixmdl.normal
